@@ -22,11 +22,13 @@ int get_numcpus()
 	char path[PATH_MAX];
 	int number = 0;
 
-	for (i = 0; i <= MAX_CPU; i++) {
+	for (i = 0; ; i++) {
 		/* check whether file exists and is readable */
 		sprintf(path, "/sys/devices/system/cpu/cpu%d/online", i);
 		if (access(path, R_OK) == 0)
 			number++;
+		else
+			break;
 	}
 	return number;
 }
@@ -185,7 +187,7 @@ void reactivate_cpus()
 	*/
 	if (num_cpu_start == 0)
 		return;
-	while (get_num_online_cpus() != num_cpu_start && cpuid < MAX_CPU) {
+	while (get_num_online_cpus() != num_cpu_start && cpuid < get_numcpus()) {
 		nc = get_num_online_cpus();
 		if (nc == num_cpu_start)
 			return;
