@@ -32,11 +32,11 @@
 #define DASD_IOCTL_LETTER 'D'
 
 /*
- * struct dasd_information_t
+ * struct dasd_information2_t
  * represents any data about the device, which is visible to userspace.
  *  including format and features.
  */
-typedef struct dasd_information_t {
+typedef struct dasd_information2_t {
         unsigned int devno;           /* S/390 devno                        */
         unsigned int real_devno;      /* for aliases                        */
         unsigned int schid;           /* S/390 subchannel identifier        */
@@ -56,7 +56,17 @@ typedef struct dasd_information_t {
         unsigned int confdata_size;
         char characteristics[64];     /* from read_device_characteristics   */
         char configuration_data[256]; /* from read_configuration_data       */
-} dasd_information_t;
+	unsigned int format;          /* format info like formatted/cdl/ldl/... */
+	unsigned int features;        /* dasd features like 'ro',...            */
+	unsigned int reserved0;       /* reserved for further use ,...          */
+	unsigned int reserved1;       /* reserved for further use ,...          */
+	unsigned int reserved2;       /* reserved for further use ,...          */
+	unsigned int reserved3;       /* reserved for further use ,...          */
+	unsigned int reserved4;       /* reserved for further use ,...          */
+	unsigned int reserved5;       /* reserved for further use ,...          */
+	unsigned int reserved6;       /* reserved for further use ,...          */
+	unsigned int reserved7;       /* reserved for further use ,...          */
+} dasd_information2_t;
 
 
 struct dasd_eckd_characteristics {
@@ -133,6 +143,19 @@ struct dasd_eckd_characteristics {
 	unsigned int long_no_cyl;
 } __attribute__ ((packed));
 
+/*
+ * Represents possible format modes that can be specified when formatting
+ * a DASD.
+ */
+typedef enum format_mode_t {
+	FULL,		/* default mode */
+	QUICK,		/* format only the first 2 tracks */
+	EXPAND,		/* search for unformatted area and format only that part*/
+} format_mode_t;
+
+static const char mode_str[3][10] = {
+	"Full", "Quick", "Expand"
+};
 
 /* 
  * struct format_data_t
@@ -158,6 +181,43 @@ typedef struct format_data_t {
 #define DASD_FMT_INT_COMPAT 8 /* use OS/390 compatible disk layout */
 #define DASD_FMT_INT_FMT_NOR0 16 /* remove permission to write record zero */
 
+/*
+ * struct format_check_t
+ * represents all data necessary to evaluate the format of
+ * different tracks of a dasd
+ */
+typedef struct format_check_t {
+	/* Input */
+	struct format_data_t expect;
+
+	/* Output */
+	unsigned int result;            /* Error indication (DASD_FMT_ERR_*) */
+	unsigned int unit;              /* Track that is in error */
+	unsigned int rec;               /* Record that is in error */
+	unsigned int num_records;       /* Records in the track in error */
+	unsigned int blksize;           /* Block-size of first record in error */
+	unsigned int key_length;        /* Key length of first record in error */
+} format_check_t;
+
+/*
+ * values to be used in format_check_t for indicating
+ * possible format errors
+ */
+#define DASD_FMT_ERR_TOO_FEW_RECORDS	1
+#define DASD_FMT_ERR_TOO_MANY_RECORDS	2
+#define DASD_FMT_ERR_BLKSIZE		3
+#define DASD_FMT_ERR_RECORD_ID		4
+#define DASD_FMT_ERR_KEY_LENGTH		5
+
+/*
+ * values to be used for dasd_information2_t.format
+ * 0x00: NOT formatted
+ * 0x01: Linux disc layout
+ * 0x02: Common disc layout
+ */
+#define DASD_FORMAT_NONE 0
+#define DASD_FORMAT_LDL  1
+#define DASD_FORMAT_CDL  2
 
 /* Disable the volume (for Linux) */
 #define BIODASDDISABLE _IO(DASD_IOCTL_LETTER,0) 
@@ -165,11 +225,14 @@ typedef struct format_data_t {
 #define BIODASDENABLE  _IO(DASD_IOCTL_LETTER,1)  
 
 /* Get information on a dasd device (enhanced) */
-#define BIODASDINFO   _IOR(DASD_IOCTL_LETTER,1,dasd_information_t)
+#define BIODASDINFO2   _IOR(DASD_IOCTL_LETTER, 3, dasd_information2_t)
 
 /* #define BIODASDFORMAT  _IOW(IOCTL_LETTER,0,format_data_t) , deprecated */
 #define BIODASDFMT     _IOW(DASD_IOCTL_LETTER,1,format_data_t) 
 
+/* Check device format according to format_data_t */
+#define BIODASDCHECKFMT _IOWR(DASD_IOCTL_LETTER, 2, format_check_t)
+
 /****************************************************************************
  * SECTION: Further IOCTL Definitions  (see fs.h and hdreq.h )              *
  ****************************************************************************/
@@ -214,7 +277,8 @@ typedef struct format_data_t {
 	if (*endptr) ERRMSG_EXIT(EXIT_MISUSE,"%s: " str " "    \
 	"is in invalid format\n",prog_name);}
 
-#define dasdfmt_getopt_string "b:n:l:f:d:m:r:hpPLtyvVFk"
+#define OPT_CHECK 128
+#define dasdfmt_getopt_string "b:n:l:f:d:m:M:r:hpPLtyvVFkC"
 
 static struct option dasdfmt_getopt_long_options[]=
 {
@@ -233,6 +297,9 @@ static struct option dasdfmt_getopt_long_options[]=
         { "help",        0, 0, 'h'},
         { "keep_volser", 0, 0, 'k'},
         { "norecordzero",  0, 0, 'z'},
+	{ "check_host_count",  0, 0, 'C'},
+	{ "mode",	 1, 0, 'M'},
+	{ "check",	 0, 0, OPT_CHECK},
         {0, 0, 0, 0}
 };
 
@@ -247,9 +314,8 @@ typedef struct bootstrap2 {
 } __attribute__ ((packed)) bootstrap2_t;
 
 typedef struct dasdfmt_info {
-        int   devno;
+	dasd_information2_t dasd_info;
         char  devname[PATH_MAX];
-        int   usage_count;
         int   verbosity;
         int   testmode;
         int   withoutprompt;
@@ -265,6 +331,9 @@ typedef struct dasdfmt_info {
         int   node_specified;
         int   device_id;
         int   keep_volser;
+	int   force_host;
+	int   layout_specified;
+	int   check;
 } dasdfmt_info_t;
 
 
