@@ -369,7 +369,10 @@ fdasd_usage (void)
                 "                         found in CONFIGFILE\n"
 		"-i, --volser             Print volume serial\n"
 		"-p, --table              Print partition table\n"
-		"-f, --force              Force fdasd to work on non DASD devices\n");
+		"-f, --force              Force fdasd to work on non DASD devices\n"
+		"-C, --check_host_count   Force fdasd to check the host access\n"
+		"                         open count to ensure the device is not\n"
+		"                         online on another operating system instance\n");
 }
 
 
@@ -572,6 +575,9 @@ fdasd_parse_options (fdasd_anchor_t *anc, struct fdasd_options *options,
 			anc->force_virtual++;
 			fdasd_parse_force_options(anc, optarg);
 			break;
+		case 'C':
+			anc->force_host++;
+			break;
 		case -1:
 			/* End of options string - start of devices list */
 			break;
@@ -824,6 +830,7 @@ fdasd_verify_device (fdasd_anchor_t *anc, char *name)
 {
 	struct stat dst;
 	char err_str[ERROR_STRING_SIZE];
+	int count;
 
 	if ((stat(name, &dst)) < 0 ) {
 		snprintf(err_str, ERROR_STRING_SIZE,
@@ -856,6 +863,29 @@ fdasd_verify_device (fdasd_anchor_t *anc, char *name)
 		fdasd_error(anc, device_verification_failed, err_str);
 	}
 
+	count = u2s_get_host_access_count(name);
+	if (anc->force_host) {
+		if (count > 1) {
+			snprintf(err_str, ERROR_STRING_SIZE,
+				 "Disk %s is online on operating system instances in %d different LPARs.\n"
+				 "Note: Your installation might include z/VM systems that are configured to\n"
+				 "automatically vary on disks, regardless of whether they are subsequently used.\n",
+				 name, count);
+			fdasd_error(anc, device_verification_failed, err_str);
+		} else if (count < 0) {
+			snprintf(err_str, ERROR_STRING_SIZE,
+				 "Hosts access information not available for disk %s.\n",
+				 name);
+			fdasd_error(anc, device_verification_failed, err_str);
+		}
+	} else if (count > 1)
+		printf("\nWARNING:\n"
+		       "Disk %s is online on operating system instances in %d different LPARs.\n"
+		       "Ensure that the disk is not being used by a system outside your LPAR.\n"
+		       "Note: Your installation might include z/VM systems that are configured to\n"
+		       "automatically vary on disks, regardless of whether they are subsequently used.\n\n",
+		       name, count);
+
 	if (anc->verbose)
 		printf("Verification successful for '%s' (%d/%d)\n", name,
 		       (unsigned short) major(dst.st_rdev),
