@@ -157,22 +157,23 @@ struct dasd_eckd_characteristics {
 #define PARTITION_GPFS 5
 
 static struct option fdasd_long_options[] = {
-	{ "version",     no_argument,       NULL, 'v'},
-	{ "auto",        no_argument,       NULL, 'a'},
-	{ "silent",      no_argument,       NULL, 's'},
-	{ "verbose",     no_argument,       NULL, 'r'},
-	{ "label",       required_argument, NULL, 'l'},
-	{ "config",      required_argument, NULL, 'c'},
-	{ "help",        no_argument,       NULL, 'h'},
-	{ "table",       no_argument,       NULL, 'p'},
-	{ "volser",      no_argument,       NULL, 'i'},
-	{ "keep_volser", no_argument,       NULL, 'k'},
-	{ "force",       optional_argument, NULL, 'f'},
-	{ 0,             0,                 0,    0  }
+	{ "version",          no_argument,       NULL, 'v'},
+	{ "auto",             no_argument,       NULL, 'a'},
+	{ "silent",           no_argument,       NULL, 's'},
+	{ "verbose",          no_argument,       NULL, 'r'},
+	{ "label",            required_argument, NULL, 'l'},
+	{ "config",           required_argument, NULL, 'c'},
+	{ "help",             no_argument,       NULL, 'h'},
+	{ "table",            no_argument,       NULL, 'p'},
+	{ "volser",           no_argument,       NULL, 'i'},
+	{ "keep_volser",      no_argument,       NULL, 'k'},
+	{ "force",            optional_argument, NULL, 'f'},
+	{ "check_host_count", no_argument,       NULL, 'C'},
+	{ 0,                  0,                 0,    0  }
 };
 
 /* Command line option abbreviations */
-static const char option_string[] = "vasrl:c:hpikf::";
+static const char option_string[] = "vasrl:c:hpikf::C";
 
 struct fdasd_options {
 	char *device;
@@ -214,6 +215,7 @@ typedef struct fdasd_anchor {
 	int print_volser;
 	int keep_volser;
 	int force_virtual;
+	int force_host;
 	int big_disk;
 	int silent;
 	int verbose;
