@@ -113,8 +113,10 @@ char *ht_mount_point_get(const char *fs_type)
 	if (!mounts)
 		ERR_EXIT_ERRNO("Could not find \"%s\" mount point", fs_type);
 	while ((mntbuf = getmntent(mounts)) != NULL) {
-		if (strcmp(mntbuf->mnt_type, fs_type) == 0)
+		if (strcmp(mntbuf->mnt_type, fs_type) == 0) {
+			endmntent(mounts);
 			return ht_strdup(mntbuf->mnt_dir);
+		}
 	}
 	endmntent(mounts);
 	return NULL;
@@ -184,9 +186,9 @@ void ht_print_head(const char *sys)
 		ht_bold_off();
 		hyptop_printf(" ");
 	}
-	hyptop_printf("CPU-");
+	hyptop_printf("cpu-");
 	ht_underline_on();
-	hyptop_printf("T");
+	hyptop_printf("t");
 	ht_underline_off();
 	hyptop_printf(": ");
 
