@@ -17,12 +17,13 @@
 #include <fcntl.h>
 #include <sys/sysmacros.h>
 #include <dirent.h>
+#include <stdlib.h>
 
 #include "u2s.h"
 
 #define DEV_BUFFER_LENGTH 20
 #define PATH_BUFFER_LENGTH 256
-#define BUSIDSIZE 8
+#define BUSIDSIZE 9
 
 #define BLOCKPATH "/sys/block/"
 #define DEVICE_LINK "device"
@@ -110,7 +111,7 @@ static int extract_busid(char *name, char *busid) {
 	if (!start)
 		return -1;
 	start++;
-	strcpy(busid, start);
+	strncpy(busid, start, BUSIDSIZE);
 	return 0;
 };
 
@@ -228,7 +229,7 @@ static int find_busid_in_sysfs(char *dev, char *busid) {
 static int find_busid_in_proc(int maja, int mina, char *busid)
 {
 	FILE *filp;
-	char bus[BUSIDSIZE + 1];
+	char bus[BUSIDSIZE];
 	int majb, minb, rc;
 
 	rc = -1;
@@ -236,10 +237,10 @@ static int find_busid_in_proc(int maja, int mina, char *busid)
 	filp = fopen("/proc/dasd/devices", "r");
 	if (!filp)
 		return rc;
-	while (fscanf(filp, "%[^(] %*s at ( %d : %d %*[^\n]\n",
+	while (fscanf(filp, "%[^(] %*[^)] ) at ( %d : %d %*[^\n]\n",
 		      bus, &majb, &minb) != EOF) {
 		if ((maja == majb) && (mina == minb)) {
-			strncpy(busid, bus, BUSIDSIZE + 1);
+			strncpy(busid, bus, BUSIDSIZE);
 			rc = 0;
 			break;
 		}
@@ -282,3 +283,45 @@ int u2s_getbusid(char *devicenode, char *busid)
 
 	return rc;
 }
+
+/*
+ * Attempts to find the sysfs entry for the given busid and reads
+ * the contents of a specified attribute to the buffer
+ */
+int u2s_read_attribute(char *busid, char *attribute, char *buffer,
+		       size_t count)
+{
+	char path[100];
+	int rc, fd;
+	ssize_t rcount;
+
+	rc = 0;
+	snprintf(path, sizeof(path), "/sys/bus/ccw/devices/%s/%s",
+		 busid, attribute);
+	fd = open(path, O_RDONLY);
+	if (fd < 0)
+		return errno;
+	rcount = read(fd, buffer, count);
+	if (rcount < 0)
+		rc = errno;
+	close(fd);
+	return rc;
+}
+
+int u2s_get_host_access_count(char *devicenode)
+{
+	char busid[BUSIDSIZE];
+	unsigned long value;
+	char buffer[10];
+	char *endp;
+
+	u2s_getbusid(devicenode, busid);
+	u2s_read_attribute(busid, "host_access_count", buffer, sizeof(buffer));
+
+	value = strtoul(buffer, &endp, 0);
+
+	if (endp == buffer)
+		return -EINVAL;
+
+	return value;
+}
