@@ -31,7 +31,7 @@ extern int proc_fd;
 /**********************************************************************
  * str_to_oid_conv():
  *  This function converts an OID string in an OID u_long array used
- *  by ucd-snmp. 
+ *  by net-snmp.
  *  parameters:
  *  IN  char* uc_oid: OID string separated by dots  
  *  OUT oid*  ul_oid: OID u_long array
@@ -95,7 +95,7 @@ int str_to_oid_conv ( char* uc_oid, oid* ul_oid )
 
 /**********************************************************************
  * oid_to_str_conv():
- *  This function converts a ucd-snmp OID u_long array into an OID        
+ *  This function converts a net-snmp OID u_long array into an OID
  *  string separated by dots.
  *  parameters:
  *  IN  oid*    ul_oid: OID u_long array
@@ -185,7 +185,7 @@ int search_oid ( oid* s_oid, size_t len, TABLE_OID* lhead, TABLE_OID** curr  )
 {
 
   /* loop through list and compare OIDs */
-  /* fyi - snmp_oid_compare() is a function from the ucd-snmp agent extension API */
+  /* fyi - snmp_oid_compare() is a function from the net-snmp agent extension API */
   for( *curr=lhead; (*curr)->next != NULL; *curr=(*curr)->next )    
     {
       switch
@@ -236,7 +236,7 @@ int search_top_oid ( oid* s_oid, size_t len,
 {
 
   /* loop through list and compare OIDs */
-  /* snmp_oid_compare() is a taken from the ucd-snmp agent extension API */
+  /* snmp_oid_compare() is a taken from the net-snmp agent extension API */
   for( *curr=lhead; (*curr)->next != NULL; *curr=(*curr)->next )    
     {
       /* fully qualified OID must be greater than our Toplevel OID */
@@ -333,7 +333,7 @@ int delete_oid( oid* d_oid, size_t len, TABLE_OID* lhead )
   TABLE_OID *curr, *del_entry;
 
   /* loop through list and compare OIDs  */
-  /* snmp_oid_compare() is taken from the ucd-snmp agent extension API */
+  /* snmp_oid_compare() is taken from the net-snmp agent extension API */
   for( curr=lhead; curr->next != NULL; curr=curr->next )    
     {
       if ( snmp_oid_compare( d_oid, len, curr->next->pObjid, 
@@ -518,7 +518,7 @@ int search_index ( char* s_index, REG_INDICES* lhead, REG_INDICES** curr  )
 {
 
   int  oid_len1, oid_len2;
-  oid  ind_oid1[MAX_OID_LEN];           /* temporary ucd-snmp oids */
+  oid  ind_oid1[MAX_OID_LEN];           /* temporary net-snmp oids */
   oid  ind_oid2[MAX_OID_LEN];
 
   /* loop through list and compare indices */
@@ -558,7 +558,7 @@ int search_index ( char* s_index, REG_INDICES* lhead, REG_INDICES** curr  )
 /**********************************************************************
  * register_tables()
  *  Parses MIB information returned by IPAssists and registers OID 
- *  suffixes with ucd-snmp subagent driving code using the REGISTER_MIB
+ *  suffixes with net-snmp subagent driving code using the REGISTER_MIB
  *  macro. Also puts data from the MIB information returned by IPAssists
  *  into local data structures to maintain index information.
  *  
@@ -599,7 +599,7 @@ int register_tables ( void* mib_data,
   int  i, j, suf_def, suf_cnt, src_oid, src_ind;   
   int  oid_len, oid_acc, oid_typ;         
 
-  oid  t_oid[MAX_OID_LEN];           /* temporary ucd-snmp oid */
+  oid  t_oid[MAX_OID_LEN];           /* temporary net-snmp oid */
   oid  *top_oid;
   char *new_index;                         
   char toid_str[MAX_OID_STR_LEN];
@@ -612,7 +612,7 @@ int register_tables ( void* mib_data,
   TABLE_OID      *oid_ptr, *ins_oid = NULL; /* ptr into Toplevel OID linked list */
   REG_INDICES    *ind_ptr;        /* ptr into index linked list */
  
-  /* ptr to ucd-snmp variable13 structs that will contain the suffix
+  /* ptr to net-snmp variable13 structs that will contain the suffix
      information registered with subagent driving code */
   struct variable13 *table_vars, *new_area;
 
@@ -633,7 +633,7 @@ int register_tables ( void* mib_data,
     /* adjust parse ptr to next Toplevel OID (skip padding) */	  
     mib_data_ptr = (int*) (PTR_ALIGN4(mib_data_ptr));	  
     
-    /* convert string OID to ucd-snmp oid type */
+    /* convert string OID to net-snmp oid type */
     strncpy( toid_str, (char*) mib_data_ptr, MAX_OID_STR_LEN ); 
     toid_str[ MAX_OID_STR_LEN-1 ] = '\0';
     oid_len = str_to_oid_conv( (char*) mib_data_ptr, t_oid ); 
@@ -762,7 +762,7 @@ int register_tables ( void* mib_data,
 		/* reassign table_vars */
                 table_vars = new_area;
 
-	      /* convert suffix OID string to ucd-snmp oid type */
+	      /* convert suffix OID string to net-snmp oid type */
 	      oid_len = str_to_oid_conv( (char*) mib_data_ptr, t_oid ); 
 	      if ( oid_len == 0 ) {
 		get_time( time_buf );      
@@ -853,7 +853,7 @@ int register_tables ( void* mib_data,
       } /* end for (j) */
 
     /* new Toplevel OID?: yes, then register with agent to add this table */
-    /* note - register_mib() is taken from the ucd-snmp agent extension API */
+    /* note - register_mib() is taken from the net-snmp agent extension API */
     
     if ( src_oid == OID_NOT_FOUND )  
       {	    
@@ -897,7 +897,7 @@ int register_tables ( void* mib_data,
  * header_osa_table()
  * Compare 'name' to vp->name for the best match or an exact match.
  * Store result OID in 'name', including the index that matches best.
- * Return matching ucd-snmp ifIndex to caller.
+ * Return matching net-snmp ifIndex to caller.
  * 
  * parameters:
  * IN    struct variable *vp      - ptr to registered subagent MIB data
