@@ -3,9 +3,9 @@
  *
  * OSA-E subagent main module
  *
- * This subagent extends the ucd-snmp master agent to support
+ * This subagent extends the net-snmp master agent to support
  * the Direct SNMP feature of zSeries OSA-E network cards. 
- * ucd-snmp AgentX support must be enabled to allow the 
+ * net-snmp AgentX support must be enabled to allow the
  * subagent connecting to the master agent (snmpd).  
  *
  * Copyright IBM Corp. 2002, 2007
@@ -173,13 +173,8 @@ int main( int argc, char *argv[] )
 				pid_file_set = 1;
 				break;
 			case 'x':
-#ifdef NETSNMP5
 				netsnmp_ds_set_string(NETSNMP_DS_APPLICATION_ID,
 					NETSNMP_DS_AGENT_X_SOCKET, optarg);
-#else
-				ds_set_string(NETSNMP_DS_APPLICATION_ID,
-					NETSNMP_DS_AGENT_X_SOCKET, optarg);
-#endif
 				break;
 			default:
 				fprintf(stderr, "Try 'osasnmpd --help' for more"
@@ -220,21 +215,12 @@ int main( int argc, char *argv[] )
 	}
 
 
-#ifdef NETSNMP5
 	snmp_log(LOG_INFO, "IBM OSA-E NET-SNMP 5.1.x subagent version  %s\n",
 		 RELEASE_STRING );
-#else
-	snmp_log(LOG_INFO, "IBM OSA-E ucd-snmp 4.2.x subagent version %s\n",
-		 RELEASE_STRING );
-#endif
 
 	/* make us a agentx client. */
-#ifdef NETSNMP5
 	netsnmp_ds_set_boolean(NETSNMP_DS_APPLICATION_ID, NETSNMP_DS_AGENT_ROLE,
 			       1); 
-#else
-	ds_set_boolean(NETSNMP_DS_APPLICATION_ID, NETSNMP_DS_AGENT_ROLE, 1);
-#endif	
 	
 	/* initialize the agent library */
 	if ( init_agent("osasnmpd") != 0 ) {
