@@ -2,22 +2,122 @@
 #
 # dbginfo.sh - Tool to collect runtime, configuration, and trace information
 #
-# Copyright IBM Corp. 2002, 2014
+# Copyright IBM Corp. 2002, 2016
 #
 
 # Switching to neutral locale
 LC_ALL=C
 export LC_ALL
 
-# The kernel release version as delivered from uname -r
-readonly KERNEL_RELEASE_VERSION=$(uname -r 2>/dev/null)
+# The general name of this script
+readonly SCRIPTNAME="${0##*/}"
+
+
+########################################
+# print version info
+print_version() {
+    cat <<EOF
+${SCRIPTNAME}: Debug information script version %S390_TOOLS_VERSION%
+Copyright IBM Corp. 2002, 2016
+EOF
+}
+
+
+########################################
+# print how to use this script
+print_usage()
+{
+    print_version
+
+    cat <<EOF
+
+
+Usage: ${SCRIPTNAME} [OPTIONS]
+
+This script collects runtime, configuration and trace information about
+your Linux on System z installation for debugging purposes.
+
+It also traces information about z/VM if the Linux runs under z/VM.
+
+
+The collected information is written to a TAR archive named
+
+    /tmp/DBGINFO-[date]-[time]-[hostname]-[processorid].tgz
+
+where [date] and [time] are the date and time when debug data is collected.
+[hostname] indicates the hostname of the system the data was collected from.
+The [processorid] is taken from the processor 0 and indicates the processor
+identification.
+
+Options:
+
+	-d|--directory     specify the directory where the data collection
+			   stores the temporary data and the final archive.
+	-h|--help          print this help
+	-v|--version       print version information
+
+
+Please report bugs to: linux390@de.ibm.com
+
+EOF
+}
+
+######################################
+# Verification to run as root
+#
+if test "$(/usr/bin/id -u 2>/dev/null)" -ne 0; then
+    echo "${SCRIPTNAME}: Error: You must be user root to run \"${SCRIPTNAME}\"!"
+    exit 1
+fi
+
+#######################################
+# Parsing the command line
+#
+paramWORKDIR_BASE="/tmp/"
+
+while [ ${#} -gt 0 ]; do
+    case ${1} in
+	--help|-h)
+	    print_usage
+	    exit 0
+	    ;;
+	--version|-v)
+	    print_version
+	    exit 0
+	    ;;
+	--directory|-d)
+	    paramWORKDIR_BASE=${2}
+	    shift
+	    ;;
+	-*|--*|*)
+	    echo
+	    echo "${SCRIPTNAME}: invalid option \"${1}\""
+	    echo "Try '${SCRIPTNAME} --help' for more information"
+	    echo
+	    exit 1
+	    ;;
+    esac
+    shift
+done
+
+if test -z "${paramWORKDIR_BASE}"; then
+    echo "${SCRIPTNAME}: Error: No directory specified for data collection!"
+    echo
+    exit 1
+fi
+if test ! -d "${paramWORKDIR_BASE}"; then
+    echo "${SCRIPTNAME}: Error: The specified directory \"${paramWORKDIR_BASE}\" does not exist!"
+    echo
+    exit 1
+fi
+
 
 ########################################
 # Global used variables
 #
 
-# The general name of this script
-readonly SCRIPTNAME="${0##*/}"
+# The base working directory
+readonly WORKDIR_BASE="$(echo "${paramWORKDIR_BASE}" | sed -e 's#/$##')/"
 
 # The terminal
 readonly TERMINAL=$(tty 2>/dev/null)
@@ -25,6 +125,9 @@ readonly TERMINAL=$(tty 2>/dev/null)
 # The hostname of the system
 readonly SYSTEMHOSTNAME=$(hostname -s 2>/dev/null)
 
+# The kernel release version as delivered from uname -r
+readonly KERNEL_RELEASE_VERSION=$(uname -r 2>/dev/null)
+
 # The processor ID for the first processor
 readonly PROCESSORID=$(grep -E ".*processor 0:.*" /proc/cpuinfo | sed 's/.*identification[[:space:]]*\=[[:space:]]*\([[:alnum:]]*\).*/\1/g')
 
@@ -34,9 +137,6 @@ readonly PROCESSORVERSION=$(grep -E ".*processor 0:.*" /proc/cpuinfo | sed 's/.*
 # The current date
 readonly DATETIME=$(date +%Y-%m-%d-%H-%M-%S 2>/dev/null)
 
-# The base working directory
-readonly WORKDIR_BASE="/tmp/"
-
 # The current working directory for the actual script execution
 if test -z "${PROCESSORID}"; then
     readonly WORKDIR_CURRENT="DBGINFO-${DATETIME}-${SYSTEMHOSTNAME:-localhost}"
@@ -53,6 +153,9 @@ readonly WORKARCHIVE="${WORKDIR_BASE}${WORKDIR_CURRENT}.tgz"
 # The log file of activities from this script execution
 readonly LOGFILE="${WORKPATH}dbginfo.log"
 
+# The file to indicate that another instance of the script is already running
+readonly LOCKFILE="/tmp/${SCRIPTNAME}.lock"
+
 # File that includes output of Linux commands
 readonly OUTPUT_FILE_CMD="${WORKPATH}runtime.out"
 
@@ -68,11 +171,17 @@ readonly OUTPUT_FILE_OSAOAT="${WORKPATH}osa_oat"
 # File that includes the output of journalctl
 readonly OUTPUT_FILE_JOURNALCTL="${WORKPATH}journalctl.out"
 
+# File that includes the output of OpenVSwitch
+readonly OUTPUT_FILE_OVS="${WORKPATH}openvswitch"
+
+# File that includes the KVM domain xml file
+readonly OUTPUT_FILE_XML="${WORKPATH}domain_xml"
+
 # Mount point of the debug file system
 readonly MOUNT_POINT_DEBUGFS="/sys/kernel/debug"
 
 # The amount of steps running the whole collections
-readonly COLLECTION_COUNT=7
+readonly COLLECTION_COUNT=10
 
 # The kernel version (e.g. '2' from 2.6.32 or '3' from 3.2.1)
 readonly KERNEL_VERSION=$(uname -r 2>/dev/null | cut -d'.' -f1)
@@ -168,8 +277,8 @@ fi
 if test "${LINUX_SUPPORT_SYSFSDBF}" -eq 1; then
     if test -e /proc/s390dbf; then
 	PROCFILES="${PROCFILES}\
-          $(find /proc/s390dbf -type f -not -path "*/raw" -not -path "*/flush" 2>/dev/null)\
-          "
+	  $(find /proc/s390dbf -type f -not -path "*/raw" -not -path "*/flush" 2>/dev/null)\
+	  "
     fi
 fi
 
@@ -184,36 +293,46 @@ LOGFILES="\
   /var/log/dracut.log*\
   /var/log/IBMtape.trace\
   /var/log/IBMtape.errorlog\
+  /var/log/libvirt\
   /var/log/lin_tape.trace\
   /var/log/lin_tape.errorlog\
   /var/log/messages*\
   /var/log/sa\
   /var/log/yum.log\
+  /var/log/openvswitch/ovs-vswitchd.log\
+  /var/log/openvswitch/ovsdb-server.log\
   "
 
 ########################################
 
 CONFIGFILES="\
+  /boot/grub2/grub.cfg\
+  /boot/zipl/active_devices.txt\
+  /boot/zipl/config\
   /etc/*.conf\
   /etc/anacrontab\
   /etc/auto.*\
   /etc/cron.*\
   /etc/crontab\
   /etc/crypttab\
+  /etc/default\
   /etc/depmod.d\
   /etc/dracut.conf.d\
   /etc/exports\
   /etc/fstab\
   /etc/groups\
+  /etc/grub.d\
   /etc/hosts*\
   /etc/iscsi\
   /etc/inittab\
+  /etc/libvirt\
   /etc/logrotate.d\
   /etc/lvm\
   /etc/modprobe.conf*\
   /etc/modprobe.d\
   /etc/mtab\
   /etc/multipath\
+  /etc/network\
   /etc/networks\
   /etc/pam.d\
   /etc/profile\
@@ -227,6 +346,7 @@ CONFIGFILES="\
   /etc/sysconfig\
   /etc/sysctl.d\
   /etc/syslog*\
+  /etc/systemd\
   /etc/udev*\
   /etc/xinet.d\
   /etc/*release\
@@ -254,6 +374,8 @@ CMDS="uname -a\
   :ip neigh list\
   :ip link show\
   :ip ntable\
+  :ip a sh\
+  :firewall-cmd --list-all\
   :ipcs -a\
   :netstat -pantu\
   :netstat -s\
@@ -262,6 +384,16 @@ CMDS="uname -a\
   :dmsetup table\
   :dmsetup table --target multipath\
   :dmsetup status\
+  :multipathd -k'show config'\
+  :multipathd -k'show maps'\
+  :multipathd -k'show topo'\
+  :multipathd -k'show paths'\
+  :multipathd -k'show maps stats'\
+  :multipathd -k'show maps status'\
+  :multipathd -k'show status'\
+  :multipathd -k'show daemon'\
+  :multipathd -k'show blacklist'\
+  :multipathd -k'show devices'\
   :multipath -v6 -ll\
   :multipath -d\
   :multipath -t\
@@ -271,6 +403,7 @@ CMDS="uname -a\
   :lscpu -ae\
   :lsmem\
   :lsdasd\
+  :lsdasd -u\
   :ziorep_config -ADM\
   :lsmod\
   :lsdev\
@@ -299,6 +432,10 @@ CMDS="uname -a\
   :cat /root/.bash_history\
   :env\
   :journalctl --all --no-pager --since=$(date -d '5 day ago' +%Y-%m-%d) --until=now --lines=50000 > ${OUTPUT_FILE_JOURNALCTL}\
+  :systemd-delta\
+  :systemctl --all --no-pager show\
+  :systemctl --all --no-pager list-units\
+  :systemctl --all --no-pager list-unit-files\
   "
 
 ########################################
@@ -319,6 +456,7 @@ VM_CMDS="q userid\
   :q v pav\
   :q v sw\
   :q v st\
+  :q v nic\
   :q st\
   :q xstore\
   :q xstore user system\
@@ -359,15 +497,14 @@ VM_CMDS="q userid\
   :ind sp\
   :ind user\
   "
-
-
 ###############################################################################
 
 ########################################
 collect_cmdsout() {
     local cmd
-    local ifs_orig="${IFS}"
+    local ifs_orig
 
+    ifs_orig="${IFS}"
     pr_syslog_stdout "1 of ${COLLECTION_COUNT}: Collecting command output"
 
     IFS=:
@@ -386,15 +523,20 @@ collect_vmcmdsout() {
     local cp_command
     local vm_cmds
     local vm_userid
-    local module_loaded=1
-    local ifs_orig="${IFS}"
+    local module_loaded
+    local ifs_orig
+    local cp_buffer_size
+    local rc_buffer_size
+
+    module_loaded=1
+    ifs_orig="${IFS}"
 
     if echo "${RUNTIME_ENVIRONMENT}" | grep -qi "z/VM" >/dev/null 2>&1; then
 	pr_syslog_stdout "2 of ${COLLECTION_COUNT}: Collecting z/VM command output"
 
 	if which vmcp >/dev/null 2>&1; then
 	    cp_command="vmcp"
-	    if ! lsmod 2>/dev/null | grep -q vmcp; then
+	    if ! lsmod 2>/dev/null | grep -q vmcp && modinfo vmcp >/dev/null 2>&1; then
 		modprobe vmcp && module_loaded=0 && sleep 2
 	    fi
 	elif which hcp >/dev/null 2>&1; then
@@ -409,15 +551,15 @@ collect_vmcmdsout() {
 	    pr_log_stdout " "
 	    return 1
 	fi
-	VMUSERID=$(${cp_command} q userid 2>/dev/null | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
+	vm_userid=$(${cp_command} q userid 2>/dev/null | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
 
-	vm_cmds=$(echo "${VM_CMDS}" | sed "s/VMUSERID/${VMUSERID}/g")
+	vm_cmds=$(echo "${VM_CMDS}" | sed "s/VMUSERID/${vm_userid}/g")
 
 	IFS=:
 	for vm_command in ${vm_cmds}; do
 	    IFS="${ifs_orig}"
-	    local cp_buffer_size=2
-	    local rc_buffer_size=2
+	    cp_buffer_size=2
+	    rc_buffer_size=2
 	    while test ${rc_buffer_size} -eq 2 && test ${cp_buffer_size} -lt 1024; do
 		cp_buffer_size=$(( cp_buffer_size * 2 ))
 
@@ -458,11 +600,11 @@ collect_procfs() {
 
 ########################################
 collect_sysfs() {
-    local debugfs_mounted=0
+    local debugfs_mounted
+    local dir_name
     local file_name
-    local file_names
-    local rc_mount
 
+    debugfs_mounted=0
     # Requires kernel version newer then 2.4
     if test "${LINUX_SUPPORT_SYSFS}" -eq 0; then
 	pr_syslog_stdout "4 of ${COLLECTION_COUNT}: Collecting sysfs"
@@ -484,7 +626,9 @@ collect_sysfs() {
 	    mkdir -p "${WORKPATH}${dir_name}"
 	done
 
-	find /sys -noleaf -type f -perm /444 2>/dev/null | while IFS= read -r file_name; do
+	find /sys -noleaf -type f -perm /444\
+		  -a -not -name "*trace_pipe*"\
+		  2>/dev/null | while IFS= read -r file_name; do
 	    echo " ${file_name}"
 	    if ! dd if="${file_name}" status=noxfer iflag=nonblock of="${WORKPATH}${file_name}" >/dev/null 2>&1; then
 		echo "${SCRIPTNAME}: Warning: failed to copy \"${file_name}\""
@@ -532,9 +676,11 @@ collect_configfiles() {
 
 ########################################
 collect_osaoat() {
-    local network_devices=$(lsqeth 2>/dev/null | grep "Device name" | sed 's/.*:[[:space:]]\+\([^[:space:]]*\)[[:space:]]\+/\1/g')
+    local network_devices
     local network_device
 
+    network_devices=$(lsqeth 2>/dev/null | grep "Device name" \
+                     | sed 's/.*:[[:space:]]\+\([^[:space:]]*\)[[:space:]]\+/\1/g')
     if which qethqoat >/dev/null 2>&1; then
 	if test -n "${network_devices}"; then
 	    pr_syslog_stdout "7 of ${COLLECTION_COUNT}: Collecting osa oat output"
@@ -552,21 +698,142 @@ collect_osaoat() {
     pr_log_stdout " "
 }
 
+########################################
+# OpenVSwitch
+collect_ovs() {
+    local br_list
+    local ovscmd
+    local bridge
+    local ovsbrcmd
+    local ovscmds
+    local ovsbrcmds
+
+    br_list=$(ovs-vsctl list-br)
+    ovscmds="ovs-dpctl -s show\
+            :ovs-vsctl -t 5 show\
+            :ovsdb-client dump\
+            "
+    if test -n "${br_list}"; then
+        pr_syslog_stdout "8 of ${COLLECTION_COUNT}: Collecting OpenVSwitch output"
+        IFS=:
+          for ovscmd in ${ovscmds}; do
+            IFS=${ifs_orig} call_run_command "${ovscmd}" "${OUTPUT_FILE_OVS}.out"
+          done
+        IFS="${ifs_orig}"
+
+        for bridge in ${br_list}; do
+        ovsbrcmds="ovs-ofctl show ${bridge}\
+                    :ovs-ofctl dump-flows ${bridge}\
+                    :ovs-appctl fdb/show ${bridge}\
+                    "
+         IFS=:
+          for ovsbrcmd in ${ovsbrcmds}; do
+            IFS=${ifs_orig} call_run_command "${ovsbrcmd}" "${OUTPUT_FILE_OVS}.out"
+          done
+         IFS="${ifs_orig}"
+        done
+    else
+        pr_syslog_stdout "8 of ${COLLECTION_COUNT}: Collecting OpenVSwitch output skipped"
+    fi
+
+    pr_log_stdout " "
+}
+
+########################################
+collect_domain_xml() {
+    local domain_list
+    local domain
+
+    domain_list=$(virsh list --all --name)
+    if test -n "${domain_list}"; then
+        pr_syslog_stdout "9 of ${COLLECTION_COUNT}: Collecting domain xml files"
+	  for domain in ${domain_list}; do
+	    call_run_command "virsh dumpxml ${domain}" "${OUTPUT_FILE_XML}_${domain}.xml"
+          done
+    else
+        pr_syslog_stdout "9 of ${COLLECTION_COUNT}: Collecting domain xml files skipped"
+    fi
+
+    pr_log_stdout " "
+}
+
+########################################
+post_processing() {
+    local file_mtime
+    local file_mtime_epoche
+    local tmp_file
+    local file_name
+
+    pr_syslog_stdout "10 of ${COLLECTION_COUNT}: Postprocessing"
+
+    find "${WORKPATH}etc/libvirt/qemu/" -maxdepth 1 -name "*.xml" 2>/dev/null | while IFS= read -r file_name; do
+	file_mtime_epoche=$(stat --format=%Y "${file_name}")
+	file_mtime=$(date +%Y%m%d%H%M.%S --date="@${file_mtime_epoche}")
+	tmp_file=${file_name}.$$
+
+	echo " ${file_name}"
+	if ! sed "s/\( \+passwd='\).*\('\)/\1********\2/g" "${file_name}" > "${tmp_file}"; then
+	    echo "${SCRIPTNAME}: Warning: Postprocessing failed on ${file_name}"
+	    echo
+	fi
+
+	mv "${tmp_file}" "${file_name}"
+	touch --time=mtime -t "${file_mtime}" "${file_name}"
+    done
+
+    find "${WORKPATH}etc/libvirt/" -name "auth.conf" 2>/dev/null | while IFS= read -r file_name; do
+        file_mtime_epoche=$(stat --format=%Y "${file_name}")
+        file_mtime=$(date +%Y%m%d%H%M.%S --date="@${file_mtime_epoche}")
+        tmp_file=${file_name}.$$
+
+        echo " ${file_name}"
+        if ! sed "s/\(password=\).*/\1********/g" "${file_name}" > "${tmp_file}"; then
+            echo "${SCRIPTNAME}: Warning: Postprocessing failed on ${file_name}"
+            echo
+        fi
+
+        mv "${tmp_file}" "${file_name}"
+        touch --time=mtime -t "${file_mtime}" "${file_name}"
+    done
+
+    find "${WORKPATH}" -maxdepth 1 -name "*.xml" 2>/dev/null | while IFS= read -r file_name; do
+        file_mtime_epoche=$(stat --format=%Y "${file_name}")
+        file_mtime=$(date +%Y%m%d%H%M.%S --date="@${file_mtime_epoche}")
+        tmp_file=${file_name}.$$
+
+        echo " ${file_name}"
+        if ! sed "s/\( \+passwd='\).*\('\)/\1********\2/g" "${file_name}" > "${tmp_file}"; then
+            echo "${SCRIPTNAME}: Warning: Postprocessing failed on ${file_name}"
+            echo
+        fi
+
+        mv "${tmp_file}" "${file_name}"
+        touch --time=mtime -t "${file_mtime}" "${file_name}"
+    done
+
+
+    pr_log_stdout " "
+}
+
 
 ########################################
 # Be aware that this output must be
 # redirected into a separate logfile
 call_run_command() {
-    local cmd="${1}"
-    local logfile="${2}"
-    local raw_cmd=$(echo "${cmd}" | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
+    local cmd
+    local logfile
+    local raw_cmd
+
+    cmd="${1}"
+    logfile="${2}"
+    raw_cmd=$(echo "${cmd}" | sed -ne 's/^\([^[:space:]]*\).*$/\1/p')
 
     echo "#######################################################" >> "${logfile}"
     echo "${USER}@${SYSTEMHOSTNAME:-localhost}> ${cmd}" >> "${logfile}"
 
     # check if command exists
     if ! which "${raw_cmd}" >/dev/null 2>&1; then
-        # check if command is a builtin
+	# check if command is a builtin
 	if ! command -v "${raw_cmd}" >/dev/null 2>&1; then
 	    echo "${SCRIPTNAME}: Warning: Command \"${raw_cmd}\" not available" >> "${logfile}"
 	    echo >> "${logfile}"
@@ -588,8 +855,9 @@ call_run_command() {
 ########################################
 call_collect_file() {
     local directory_name
-    local file_name="${1}"
+    local file_name
 
+    file_name="${1}"
     echo " ${file_name}"
 
     directory_name=$(dirname "${file_name}" 2>/dev/null)
@@ -607,54 +875,6 @@ call_collect_file() {
 ###############################################################################
 
 
-########################################
-# print version info
-print_version() {
-    cat <<EOF
-${SCRIPTNAME}: Debug information script version %S390_TOOLS_VERSION%
-Copyright IBM Corp. 2002, 2014
-EOF
-}
-
-
-########################################
-# print how to use this script
-print_usage()
-{
-    print_version
-
-    cat <<EOF
-
-
-Usage: ${SCRIPTNAME} [OPTIONS]
-
-This script collects runtime, configuration and trace information about
-your Linux on System z installation for debugging purposes.
-
-It also traces information about z/VM if the Linux runs under z/VM.
-
-
-The collected information is written to a TAR archive named
-
-    /tmp/DBGINFO-[date]-[time]-[hostname]-[processorid].tgz
-
-where [date] and [time] are the date and time when debug data is collected.
-[hostname] indicates the hostname of the system the data was collected from.
-The [processorid] is taken from the processor 0 and indicates the processor
-identification.
-
-Options:
-
-        -h|--help          print this help
-        -v|--version       print version information
-
-
-Please report bugs to: linux390@de.ibm.com
-
-EOF
-}
-
-
 ########################################
 # print that an instance is already running
 print_alreadyrunning() {
@@ -665,41 +885,11 @@ print_alreadyrunning() {
 
 Please check the system if another instance of '${SCRIPTNAME}' is already
 running. If this is not the case, please remove the lock file
-'${WORKDIR_BASE}${SCRIPTNAME}.lock'.
+'${LOCKFILE}'.
 EOF
 }
 
 
-########################################
-#
-commandline_parse()
-{
-    local cmdline_arg1=${1}
-    local cmdline_count=${#}
-
-    if test "${cmdline_count}" -eq 1; then
-	if test "${cmdline_arg1}" = '-h' || test "${cmdline_arg1}" = '--help'; then
-	    print_usage
-	elif test "${cmdline_arg1}" = '-v' || test "${cmdline_arg1}" = '--version'; then
-	    print_version
-	else
-	    echo
-	    echo "${SCRIPTNAME}: invalid option \"${cmdline_arg1}\""
-	    echo "Try '${SCRIPTNAME} --help' for more information"
-	    echo
-	    exit 1
-	fi
-	exit 0
-    elif test "${cmdline_count}" -ge 1; then
-	echo
-	echo "${SCRIPTNAME}: Error: Invalid number of arguments!"
-	echo
-	print_usage
-	exit 1
-    fi
-}
-
-
 ########################################
 # Setup the environment
 environment_setup()
@@ -712,11 +902,12 @@ environment_setup()
 	exit 1
     fi
 
-    if test -e "${WORKDIR_BASE}${SCRIPTNAME}".lock; then
+    if test -e "${LOCKFILE}"; then
 	print_alreadyrunning
-        exit 1
+	exit 1
     else
-	touch "${WORKDIR_BASE}${SCRIPTNAME}".lock
+	touch "${LOCKFILE}"
+	echo "${DATETIME}" > "${LOCKFILE}"
     fi
 
     if ! mkdir "${WORKPATH}" 2>/dev/null; then
@@ -724,6 +915,7 @@ environment_setup()
 	echo "       \"${WORKDIR_BASE}\" does not exist!"
 	exit 1
     fi
+    chmod 0700 "${WORKPATH}"
 }
 
 
@@ -741,12 +933,15 @@ create_package()
 	pr_stdout "       Please check the directory \"${WORKDIR_BASE}\""
 	pr_stdout "       to provide enough free available space."
     else
+	chmod 0600 "${WORKARCHIVE}"
 	pr_stdout " "
 	pr_stdout "Collected data was saved to:"
 	pr_stdout " >>  ${WORKARCHIVE}  <<"
     fi
 
     pr_stdout " "
+    pr_stdout "Review the collected data before sending to your service organization. "
+    pr_stdout " "
 }
 
 
@@ -760,7 +955,7 @@ environment_cleanup()
 	pr_stdout "       Please remove the directory manually"
 	pr_stdout " "
     fi
-    if ! rm -f "${WORKDIR_BASE}${SCRIPTNAME}".lock 2>/dev/null; then
+    if ! rm -f "${LOCKFILE}" 2>/dev/null; then
 	pr_stdout " "
 	pr_stdout "${SCRIPTNAME}: Warning: Deletion of \"${WORKDIR_BASE}${SCRIPTNAME}\" failed"
 	pr_stdout "       Please remove the file manually"
@@ -815,14 +1010,6 @@ pr_syslog_stdout()
 ###############################################################################
 # Running the script
 
-commandline_parse "${@}"
-
-# Verification to run as root
-if test "$(/usr/bin/id -u 2>/dev/null)" -ne 0; then
-    echo "${SCRIPTNAME}: Error: You must be user root to run \"${SCRIPTNAME}\"!"
-    exit 1
-fi
-
 environment_setup
 print_version
 
@@ -856,6 +1043,12 @@ collect_configfiles
 
 collect_osaoat
 
+collect_ovs
+
+collect_domain_xml
+
+post_processing
+
 create_package
 
 environment_cleanup
