@@ -18,6 +18,7 @@
 #include "misc.h"
 #include "device.h"
 #include "devtype.h"
+#include "iscsi.h"
 #include "module.h"
 #include "namespace.h"
 #include "path.h"
@@ -1024,16 +1025,24 @@ static char *ccwgroup_st_resolve_devnode(struct subtype *st,
 					 struct devnode *devnode)
 {
 	struct ccwgroup_subtype_data *data = st->data;
-	char *link, *pattern = NULL, *id = NULL, *curr, dummy;
+	char *link = NULL, *pattern = NULL, *id = NULL, *curr, dummy;
 	unsigned int cssid, ssid, devno;
 	struct ccwgroup_devid devid;
+	struct devnode *netdev = NULL;
+
+	if (devnode->type == BLOCKDEV) {
+		netdev = iscsi_get_net_devnode(devnode);
+		if (!netdev)
+			return NULL;
+		devnode = netdev;
+	}
 
 	if (devnode->type != NETDEV)
-		return NULL;
+		goto out;
 
 	link = devnode_readlink(devnode);
 	if (!link)
-		return NULL;
+		goto out;
 
 	/* ../../devices/qeth/0.0.f503/net/enccw0.0.f503/ */
 	curr = strstr(link, "/devices/");
@@ -1055,6 +1064,7 @@ static char *ccwgroup_st_resolve_devnode(struct subtype *st,
 	}
 
 out:
+	free(netdev);
 	free(pattern);
 	free(link);
 
