@@ -12,8 +12,10 @@
 #include "blkinfo.h"
 #include "ccw.h"
 #include "findmnt.h"
+#include "iscsi.h"
 #include "misc.h"
 #include "namespace.h"
+#include "net.h"
 #include "device.h"
 #include "devnode.h"
 #include "udev.h"
@@ -469,63 +471,53 @@ static struct selected_dev_node *add_failed_devid_spec(
 	return sel;
 }
 
-/* Select devices that provide the compound devnode (e.g. LVM) at path. */
-static exit_code_t select_by_compound_node(struct select_opts *select,
-					   struct util_list *selected,
-					   config_t config, read_scope_t scope,
-					   struct devtype *only_dt,
-					   struct subtype *only_st,
-					   struct util_list *devnodes,
-					   const char *path)
+/* Add a devnode for any device that is a parent device of @devnode to
+ * @result. */
+static bool add_parent_devnodes(struct util_list *result,
+				struct devnode *devnode)
 {
-	exit_code_t rc = EXIT_OK;
-	struct util_list *unselected;
+	struct util_list *devnodes;
 	struct ptrlist_node *p;
-	struct devnode *devnode;
-	struct subtype *st;
-	char *id, *str;
-	int num_selected;
+	struct devnode *d;
+	bool rc = false;
 
-	/* This is a compound block device (e.g. lvm) - select all
-	 * components. */
-	unselected = strlist_new();
-	num_selected = 0;
-	util_list_iterate(devnodes, p) {
-		devnode = p->ptr;
+	switch (devnode->type) {
+	case BLOCKDEV:
+		devnodes = blkinfo_get_ancestor_devnodes(devnode);
+		if (devnodes) {
+			rc = true;
 
-		if (!subtypes_find_by_devnode(devnode, &st, &id)) {
-			strlist_add(unselected, devnode->name);
-			continue;
+			util_list_iterate(devnodes, p)
+				ptrlist_add(result, p->ptr);
+
+			ptrlist_free(devnodes, 0);
+			break;
 		}
-
-		/* In case devtype or subtype was specified on command line,
-		 * filter out devices that do not match type. */
-		if (only_st && st != only_st)
-			goto next;
-		else if (only_dt && st->devtype != only_dt)
-			goto next;
-
-		rc = match_state_and_add(select, selected, config, scope, st,
-					 id, NULL, NULL);
-		num_selected++;
-next:
-		free(id);
+		d = iscsi_get_net_devnode(devnode);
+		if (d) {
+			ptrlist_add(result, d);
+			rc = true;
+			break;
+		}
+		break;
+	case NETDEV:
+		if (net_add_linked_devnodes(result, devnode)) {
+			rc = true;
+			break;
+		}
+		if (net_add_vlan_base(result, devnode)) {
+			rc = true;
+			break;
+		}
+		if (net_add_bonding_base(result, devnode)) {
+			rc = true;
+			break;
+		}
+		break;
+	default:
+		break;
 	}
 
-	if (num_selected == 0) {
-		/* Not a single device in the compound could be selected. */
-		warn("Could not determine device that provides %s\n", path);
-		rc = EXIT_DEVICE_NOT_FOUND;
-	} else if (!util_list_is_empty(unselected)) {
-		/* Some devices in the compound could not be selected. */
-		str = strlist_flatten(unselected, " ");
-		warn("Could not determine all devices that provide %s: %s\n",
-		     path, str);
-		free(str);
-	}
-
-	strlist_free(unselected);
-
 	return rc;
 }
 
@@ -539,9 +531,12 @@ exit_code_t select_by_devnode(struct select_opts *select,
 {
 	struct select_opts *dummy_opts = NULL;
 	struct subtype *st;
-	char *id = NULL;
-	struct util_list *devnodes;
+	char *id = NULL, *str;
+	const char *name = path ? path : devnode->name;
+	struct util_list *todos, *unresolved;
 	exit_code_t rc = EXIT_OK;
+	struct ptrlist_node *p;
+	int num_resolved = 0;
 
 	/* Allocate dummy selection options in case none were supplied. */
 	if (!select) {
@@ -549,29 +544,44 @@ exit_code_t select_by_devnode(struct select_opts *select,
 		select = dummy_opts;
 	}
 
-	if (subtypes_find_by_devnode(devnode, &st, &id)) {
-		/* In case devtype or subtype was specified on command line,
-		 * filter out devices that do not match type. */
-		if ((only_st && st != only_st) ||
-		    (only_dt && st->devtype != only_dt))
-			goto out;
+	todos = ptrlist_new();
+	ptrlist_add(todos, devnode_copy(devnode));
+	unresolved = strlist_new();
 
-		rc = match_state_and_add(select, selected, config, scope, st,
-					 id, NULL, NULL);
-	} else if (devnode->type == BLOCKDEV &&
-		   (devnodes = blkinfo_get_ancestor_devnodes(devnode))) {
-		rc = select_by_compound_node(select, selected, config, scope,
-					     only_dt, only_st, devnodes,
-					     devnode->name);
-		ptrlist_free(devnodes, 1);
-	} else {
-		rc = EXIT_DEVICE_NOT_FOUND;
-		err_t_print(err, "Could not determine device that provides "
-			    "%s\n", path ? path : devnode->name);
+	util_list_iterate(todos, p) {
+		devnode = p->ptr;
+
+		if (subtypes_find_by_devnode(devnode, &st, &id)) {
+			/* In case devtype or subtype was specified on command
+			 * line, filter out devices that do not match type. */
+			if ((only_st && st != only_st) ||
+			    (only_dt && st->devtype != only_dt))
+				goto next;
+
+			match_state_and_add(select, selected, config, scope, st,
+					    id, NULL, NULL);
+			num_resolved++;
+next:
+			free(id);
+		} else if (!add_parent_devnodes(todos, devnode))
+			strlist_add(unresolved, devnode->name);
 	}
 
-out:
-	free(id);
+	str = strlist_flatten(unresolved, " ");
+	if (num_resolved == 0) {
+		/* Not a single device could be resolved. */
+		err_t_print(err, "Could not determine device that provides "
+			    "%s (%s)\n", name, str);
+		rc = EXIT_DEVICE_NOT_FOUND;
+	} else if (!util_list_is_empty(unresolved)) {
+		/* Some devices in a compound device could not be selected. */
+		err_t_print(err, "Could not determine all devices that provide "
+			    "%s (%s)\n", name, str);
+	}
+	free(str);
+
+	ptrlist_free(todos, 1);
+	strlist_free(unresolved);
 	select_opts_free(dummy_opts);
 
 	return rc;
