@@ -39,6 +39,7 @@ struct zdsfs_info {
 	int devcount;
 	int allow_inclomplete_multi_volume;
 	int keepRDW;
+	int host_count;
 	unsigned int tracks_per_frame;
 	unsigned long long seek_buffer_size;
 	struct zdsroot *zdsroot;
@@ -765,6 +766,7 @@ static const struct fuse_opt zdsfs_opts[] = {
 	FUSE_OPT_KEY("seekbuffer=",     KEY_SEEKBUFFER),
 	ZDSFS_OPT("rdw",                keepRDW, 1),
 	ZDSFS_OPT("ignore_incomplete",  allow_inclomplete_multi_volume, 1),
+	ZDSFS_OPT("check_host_count",   host_count, 1),
 	FUSE_OPT_END
 };
 
@@ -790,7 +792,10 @@ static void usage(const char *progname)
 "                           data set are missing\n"
 "    -o tracks=N            Size of the track buffer in tracks (default 128)\n"
 "    -o seekbuffer=S        Upper limit in bytes for the seek history buffer\n"
-"                           size (default 1048576)\n", progname);
+"                           size (default 1048576)\n"
+"    -o check_host_count    Stop processing if the device is used by another\n"
+"                           operating system instance\n"
+		, progname);
 }
 
 static void zdsfs_process_device(const char *device)
@@ -1014,6 +1019,17 @@ int main(int argc, char *argv[])
 			argv[0]);
 		exit(1);
 	}
+
+	if (zdsfsinfo.host_count) {
+		/* check, print error and exit if multiple online */
+		rc = lzds_analyse_open_count(zdsfsinfo.zdsroot, 0);
+		if (rc == -EACCES)
+			goto cleanup;
+	} else {
+		/* check, print warning if multiple online */
+		lzds_analyse_open_count(zdsfsinfo.zdsroot, 1);
+	}
+
 	rc = zdsfs_verify_datasets();
 	if (rc)
 		goto cleanup;
