@@ -15,7 +15,7 @@
 #include <assert.h>
 #include "zgetdump.h"
 
-#define HDR_PER_CPU_SIZE	0x300
+#define HDR_PER_CPU_SIZE	0x4a0
 #define HDR_PER_MEMC_SIZE	0x100
 #define HDR_BASE_SIZE		0x2000
 
@@ -182,6 +182,24 @@ static void *nt_s390_prefix(void *ptr, struct dfi_cpu *cpu)
 			 sizeof(cpu->prefix), "LINUX");
 }
 
+/*
+ * Initialize vxrs_low register note
+ */
+static void *nt_s390_vxrs_low(void *ptr, struct dfi_cpu *cpu)
+{
+	return nt_init(ptr, NT_S390_VXRS_LOW, &cpu->vxrs_low,
+			 sizeof(cpu->vxrs_low), "LINUX");
+}
+
+/*
+ * Initialize vxrs_high register note
+ */
+static void *nt_s390_vxrs_high(void *ptr, struct dfi_cpu *cpu)
+{
+	return nt_init(ptr, NT_S390_VXRS_HIGH, &cpu->vxrs_high,
+			 sizeof(cpu->vxrs_high), "LINUX");
+}
+
 /*
  * Initialize prpsinfo note
  */
@@ -231,6 +249,10 @@ static void *notes_init(Elf64_Phdr *phdr, void *ptr, u64 notes_offset)
 		ptr = nt_s390_tod_preg(ptr, cpu);
 		ptr = nt_s390_ctrs(ptr, cpu);
 		ptr = nt_s390_prefix(ptr, cpu);
+		if (dfi_cpu_content_fac_check(DFI_CPU_CONTENT_FAC_VX)) {
+			ptr = nt_s390_vxrs_low(ptr, cpu);
+			ptr = nt_s390_vxrs_high(ptr, cpu);
+		}
 	}
 out:
 	ptr = nt_vmcoreinfo(ptr);
