@@ -3,22 +3,24 @@
  *
  * Helper functions
  *
- * Copyright IBM Corp. 2001, 2010
+ * Copyright IBM Corp. 2001, 2014
  * Author(s): Michael Holzheu <holzheu@linux.vnet.ibm.com>
  */
 
 #include <stdlib.h>
 #include <limits.h>
+#include <sys/time.h>
 #include "zgetdump.h"
 
 #define MAX_EXIT_FN	10
 #define MAX_DEV_RETRIES	1000
+#define PROGRESS_INTERVAL_SECS	10
 
 /*
  * Progress information
  */
 struct prog {
-	u64	addr_next;
+	time_t	time_next;
 	u64	mem_size;
 };
 
@@ -342,7 +344,7 @@ enum zg_type zg_type(struct zg_fh *zg_fh)
 void zg_progress_init(const char *msg, u64 mem_size)
 {
 	STDERR("%s:\n", msg);
-	l.prog.addr_next = 0;
+	l.prog.time_next = 0;
 	l.prog.mem_size = mem_size;
 }
 
@@ -351,12 +353,13 @@ void zg_progress_init(const char *msg, u64 mem_size)
  */
 void zg_progress(u64 addr)
 {
-	if (addr < l.prog.addr_next)
-		return;
+	struct timeval tv;
 
+	gettimeofday(&tv, NULL);
+	if ((tv.tv_sec < l.prog.time_next) && (addr < l.prog.mem_size))
+		return;
 	STDERR("  %08Lu / %08Lu MB\n", TO_MIB(addr), TO_MIB(l.prog.mem_size));
-	l.prog.addr_next += l.prog.mem_size / 6;
-	l.prog.addr_next = MIN(l.prog.addr_next, l.prog.mem_size);
+	l.prog.time_next = tv.tv_sec + PROGRESS_INTERVAL_SECS;
 }
 
 /*
