@@ -35,6 +35,7 @@ ConfigReader::ConfigReader(int *rc, const char *filename)
 	int			 line_idx = 1;
 	long long unsigned int	 tmp_lun;
 	long long unsigned int	 tmp_wwpn;
+	unsigned int		 subch1, subch2, subch3, devno1, devno2, devno3;
 
 	*rc = 0;
 
@@ -64,13 +65,14 @@ ConfigReader::ConfigReader(int *rc, const char *filename)
 		new_elem.device = (char*)malloc(lrc + 1);
 		new_elem.type = (char*)malloc(lrc + 1);
 		new_elem.multipath_device = (char*)malloc(lrc + 1);
-		lrc = sscanf(line, "%x %u:%u:%u:%u 0.0.%x:0.0.%x:%Lx:%Lx %s %u %u:%u %s %u %u:%u %s",
+		lrc = sscanf(line, "%x %u:%u:%u:%u %x.%x.%x:%x.%x.%x:%Lx:%Lx %s %u %u:%u %s %u %u:%u %s",
 		       &new_elem.chpid,
 		       &new_elem.hctl_identifier.host,
 		       &new_elem.hctl_identifier.channel,
 		       &new_elem.hctl_identifier.target,
 		       &new_elem.hctl_identifier.lun,
-		       &new_elem.subchannel, &new_elem.devno,
+		       &subch1, &subch2, &subch3,
+		       &devno1, &devno2, &devno3,
 		       &tmp_wwpn,
 		       &tmp_lun,
 		       new_elem.multipath_device, &new_elem.mp_mm,
@@ -81,12 +83,15 @@ ConfigReader::ConfigReader(int *rc, const char *filename)
 		       new_elem.type);
 		free(line);
 		line = NULL;
-		if (lrc != 18) {
+		if (lrc != 22) {
 			fprintf(stderr, "%s: Could not parse line %d"
 				" - configuration file broken?\n", toolname, line_idx);
 			*rc = -1;
 			goto out;
 		}
+		/* complete bus-IDs packed in u32 to avoid filter code changes */
+		new_elem.subchannel = ZIOREP_BUSID_PACKED(subch1, subch2, subch3);
+		new_elem.devno = ZIOREP_BUSID_PACKED(devno1, devno2, devno3);
 		new_elem.wwpn = tmp_wwpn;
 		new_elem.lun = tmp_lun;
 
@@ -364,13 +369,12 @@ void ConfigReader::host_id_not_found_error(__u32 h, int *rc) const
 		" again\n", toolname, h);
 }
 
-
 void ConfigReader::devno_not_found_error(__u32 devno, int *rc) const
 {
 	*rc = -1;
-	fprintf(stderr, "%s: Could not find bus id 0.0.%x in configuration"
+	fprintf(stderr, "%s: Could not find bus id %x.%x.%04x in configuration"
 		" file. Please check if you have the right .cfg file and try"
-		" again\n", toolname, devno);
+		" again\n", toolname, ZIOREP_BUSID_UNPACKED(devno));
 }
 
 
@@ -855,13 +859,14 @@ void ConfigReader::dump(FILE *fp) const
 	fprintf(fp, "dumping cfg....\n");
 	for (list<struct device_info>::const_iterator i = m_devices.begin();
 	      i != m_devices.end(); ++i) {
-		fprintf(fp, "%x %u %u:%u:%u:%u 0.0.%04x:0.0.%x:%016Lx:%016Lx %s %u:%u %s %u:%u %s\n",
+		fprintf(fp, "%x %u %u:%u:%u:%u %x.%x.%04x:%x.%x.%04x:%016Lx:%016Lx %s %u:%u %s %u:%u %s\n",
 		       (*i).chpid, (*i).mm_internal,
 		       (*i).hctl_identifier.host,
 		       (*i).hctl_identifier.channel,
 		       (*i).hctl_identifier.target,
 		       (*i).hctl_identifier.lun,
-		       (*i).subchannel, (*i).devno,
+		       ZIOREP_BUSID_UNPACKED((*i).subchannel),
+		       ZIOREP_BUSID_UNPACKED((*i).devno),
 		       (long long unsigned int)(*i).wwpn,
 		       (long long unsigned int)(*i).lun,
 		       ((*i).multipath_device ? (*i).multipath_device : "n/a"), (*i).mp_major,
