@@ -118,7 +118,7 @@ static int parse_params(int argc, char **argv, struct options *opts)
 	int c;
 	int index;
 	int rc;
-	__u32 tmp32;
+	__u32 tmp32, tmp32a, tmp32b;
 	long long unsigned int tmp64;
 	long tmpl;
 	char mychar;
@@ -220,13 +220,13 @@ static int parse_params(int argc, char **argv, struct options *opts)
 			opts->luns.push_back(tmp64);
 			break;
 		case 'u':
-			rc = sscanf(optarg, "0.0.%x", &tmp32);
-			if (rc != 1) {
+			rc = sscanf(optarg, "%x.%x.%x", &tmp32, &tmp32a, &tmp32b);
+			if (rc != 3) {
 				fprintf(stderr, "%s: Could not read bus-ID"
 					" %s\n", toolname, optarg);
 				return -1;
 			}
-			opts->devnos.push_back(tmp32);
+			opts->devnos.push_back(ZIOREP_BUSID_PACKED(tmp32, tmp32a, tmp32b));
 			break;
 		case 'd':
 			opts->devices.push_back(optarg);
@@ -326,8 +326,8 @@ static int check_opts(struct options *opts, ConfigReader **cfg)
 	for (list<__u32>::const_iterator i = opts->devnos.begin();
 	      i != opts->devnos.end(); ++i) {
 		if (!(*cfg)->verify_devno(*i)) {
-			fprintf(stderr, "Error: Could not find bus-ID 0.0.%04x in"
-				" configuration.\n", *i);
+			fprintf(stderr, "Error: Could not find bus-ID %x.%x.%04x in"
+				" configuration.\n", ZIOREP_BUSID_UNPACKED(*i));
 			rc = -3;
 		}
 	}
