@@ -11,19 +11,18 @@
 
 #include "cio.h"
 
-#define ECKD_BPWRT_MAX 64
-
 struct eckd_device {
 	uint32_t blk_start;
 	uint32_t blk_end;
 	uint16_t blk_size;
 	uint8_t num_heads;
 	uint8_t bpt;
-	struct subchannel_id ssid;
+	struct subchannel_id sid;
 	uint16_t devno;
 };
 
 extern struct eckd_device device;
+extern unsigned long eckd_blk_max;
 
 /*
  * Convert memory size to number of blocks
