@@ -59,7 +59,7 @@ restart:
 	memset(irb, 0, sizeof(struct irb));
 	memset(&orb, 0, sizeof(struct orb));
 
-	if (blockptr->blockct > MAX_BLOCKCT) {
+	if (blockptr->blockct >= MAX_BLOCKCT) {
 		record_number = MAX_BLOCKCT - 1;
 		blockptr->blockct -= MAX_BLOCKCT;
 	} else {
