@@ -29,6 +29,7 @@
 #include "disk.h"
 #include "error.h"
 #include "misc.h"
+#include "u2s.h"
 
 #define ECKD_CDL_DUMP_REC 3 /* Start record (0 based) for stage 2 and 1b */
 /* CDL record 2 = 148 byte, independent from bs, bootinfo is last structure */
@@ -1071,6 +1072,9 @@ install_mvdump(char* const device[], struct job_target_data* target, int count,
 	parm.num_param = count;
 	parm.timestamp = (time.tv_sec << 20) + time.tv_usec;
 	for (i = 0; i < count; i++) {
+		int dummy, ssid;
+		char busid[16];
+
 		fd = misc_open_exclusive(device[i]);
 		if (fd == -1) {
 			error_text("Could not open dump target '%s'",
@@ -1115,11 +1119,6 @@ install_mvdump(char* const device[], struct job_target_data* target, int count,
 				goto out;
 			}
 		}
-		/* Make sure target device belongs to subchannel set 0 */
-		rc = disk_check_subchannel_set(info[i]->devno,
-					       info[i]->device, device[i]);
-		if (rc)
-			goto out;
 		if (check_eckd_dump_partition(info[i])) {
 			error_text("Dump target '%s'", device[i]);
 			rc = -1;
@@ -1132,6 +1131,17 @@ install_mvdump(char* const device[], struct job_target_data* target, int count,
 		parm.param[i].num_heads = info[i]->geo.heads;
 		parm.param[i].blocksize = info[i]->phy_block_size >> 8;
 		parm.param[i].devno = info[i]->devno;
+		if (u2s_getbusid(device[i], busid)) {
+			error_text("Could not find bus-ID for '%s'", device[i]);
+			rc = -1;
+			goto out;
+		}
+		if (sscanf(busid, "%x.%x.%x", &dummy, &ssid, &dummy) != 3) {
+			error_text("Could not find bus-ID for '%s'", device[i]);
+			rc = -1;
+			goto out;
+		}
+		parm.ssid[i] = ssid;
 	}
 	if (verbose) {
 		for (i = 0; i < count; i++) {
